library(readxl)
library(ggplot2)
library(ggrepel)

rs <- read_excel("~/Desktop/root_phenotyping_naturalness.xlsx", sheet = 1)

fac <- c(1,3,2,4,2)
for(i in c(1:length(fac))) rs[,i+1] <- rs[,i+1] * fac[i]

rs$naturalness <- rowSums(rs[,2:6])

rs$throughput <- log(rs$throughput)

ggplot(rs, aes(naturalness, throughput, color=age, label = name, pch=timeseries)) + 
  geom_smooth(method='lm', se=F, color="gray", lty=2)+
  geom_label_repel(aes(naturalness, throughput, label = name), force=40) +
  geom_point(size=3) + 
  theme_classic() + 
  theme(text=element_text(size=15),
        # legend.position=c(1, 1),
        # legend.justification=c(1,1),
        legend.background = element_rect(size=0.5, linetype="solid", 
                                         colour ="black")) +
  ylab("Throughput [log(plants / hour)]") + 
  xlab("Naturalness [1*3D + 2*local_constrain + 2*infinite_growth + 3*oxygen + 4*soil]") +
  ggtitle("Root phenotyping techniques") +
  scale_colour_continuous(guide = guide_legend(title = "Age \n[rel. to whole life]"))
  
